@@ -2,6 +2,8 @@
 
 void IntegrityScanner::run()
 {
+    d_active = true;
+
     ++d_nScans;
 
     setSentinel();                              // determine d_sentinel
@@ -19,21 +21,16 @@ void IntegrityScanner::run()
 
         for (auto &cmd: ranger(d_cmdIterator, beyond))
         {
-            if (d_run.interrupted())    // terminate, suspend, reload
+            if (d_pending.hasMode(SUSPEND | RELOAD | TERMINATE))
             {
                 m1 << "integrity scan interrupted by " << 
-                            d_run.modeName() << " request" << endl;
-                return;
+                            d_pending << " request" << endl;
+                d_active = false;
             }
-
             execute(cmd);
         }
     }
 
     m3 << "policy file processed" << endl;
+    d_active = false;
 }
-
-
-
-
-
